/*----------------------------------------------------------------------------
 * File    : environ.h
 * OS      : UNIX, OS/2, DOS
 * Author  : Thomas B. Pedersen
 *
 * Copyright (c) 1994 Thomas B. Pedersen.  All rights reserved.
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that the above
 * copyright notice and the following two  paragraphs appear (1) in all 
 * source copies of this software and (2) in accompanying documentation
 * wherever the programatic interface of this software, or any derivative
 * of it, is described.
 *
 * IN NO EVENT SHALL THOMAS B. PEDERSEN BE LIABLE TO ANY PARTY FOR DIRECT,
 * INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF
 * THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF HE HAS BEEN 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * THOMAS B. PEDERSEN SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS" 
 * BASIS, AND THOMAS B. PEDERSEN HAS NO OBLIGATION TO PROVIDE MAINTENANCE,
 * SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 *
 * Description:
 *   Multi Operating System compatibility include file.
 *
 * $Id: environ_dos.h,v 1.1 1994/09/20 22:17:12 tbp Exp $
 *
 * $Log: environ_dos.h,v $
 * Revision 1.1  1994/09/20  22:17:12  tbp
 * environ.h for UNIX is now generated by configure so DOS and OS/2 must be in
 * a separate file.
 *
 * Revision 1.1  1994/09/19  20:05:30  tbp
 * Moved from h to include.
 *
 * Revision 1.1  1994/09/17  15:59:13  tbp
 * Added to repository.
 *
 *
 *--------------------------------------------------------------------------*/

#ifndef _ENVIRON_INCLUDED
#define _ENVIRON_INCLUDED


/*--------------------------------------------------------------------------*/
/*                              UNIX System V                               */
/*--------------------------------------------------------------------------*/

#ifdef UNIX

#define CREATMASK		0666
#ifndef O_BINARY
#define O_BINARY		0
#endif
#define DIR_SWITCH		'/'

#if defined(sun)
#	define PROTOTYPES		1
#	define BIG_ENDIAN		1
#	define RISC				1
#elif defined(__nonstopux)
#	define PROTOTYPES		1
#	define BIG_ENDIAN		1
#	define RISC				1
#elif defined(__linux__)
#	define PROTOTYPES		1
#	define LITTLE_ENDIAN	1
#else /* presumably Intel */
#	define SCO				1
#	define PROTOTYPES		1
#	define LITTLE_ENDIAN	1
#endif

typedef unsigned char   uchar;
#ifndef _SYS_TYPES_H
	typedef unsigned short  ushort;
	typedef unsigned long   ulong;
#endif

#endif

/*--------------------------------------------------------------------------*/
/*                               OS/2 v2.0                                  */
/*--------------------------------------------------------------------------*/

#ifdef OS2
#ifdef __BORLANDC__
#   define __STDC__ 1
#endif
#define DIR_SWITCH		'\\'
#define CREATMASK		(S_IREAD|S_IWRITE)
#define PROTOTYPES		1
#define LITTLE_ENDIAN	1

typedef unsigned char   uchar;
typedef unsigned short  ushort;
typedef unsigned long   ulong;

#endif


/*--------------------------------------------------------------------------*/
/*                                    DOS                                   */
/*--------------------------------------------------------------------------*/

#ifdef DOS

#define DIR_SWITCH		'\\'
#define CREATMASK		(S_IREAD|S_IWRITE)
#define PROTOTYPES		1
#define LITTLE_ENDIAN	1

typedef unsigned char   uchar;
typedef unsigned short  ushort;
typedef unsigned long   ulong;

#endif


#ifdef PROTOTYPES
#	define PRM(x)		x
#	define _PRM(x)		x
#	define ELLIPSIS		,...
#else
#	define PRM(x)		();
#	define _PRM(x)		()
#	define ELLIPSIS		/**/
#endif

#ifndef offsetof
#	define offsetof(s,m)		((int)&(((s *)0))->m)
#endif

#ifdef BIG_ENDIAN
#	define SWAPTOSHORT(i)	(((i) >> 8) & 0xff | (i & 0xff) << 8)
#	define SWAPTOLONG(l)	((((l) & 0xff) << 24) | (((l) & 0xff00) << 8) | \
							(((l) >> 8) & 0xff00) | (((l) >> 24) & 0xff))
#	define SWAPSHORT(i)		i = SWAPTOSHORT(i)
#	define SWAPLONG(l)		l = SWAPTOLONG(l)
#else
#	define SWAPTOSHORT(i)	i
#	define SWAPTOLONG(l)	l
#	define SWAPSHORT(i)		(void)0
#	define SWAPLONG(l)		(void)0
#	define SWAP(l)			(void)0
#endif


#endif

/* end-of-file */
